diff src/plugin.h @ 5949:90d0849abd3c

[gaim-migrate @ 6393] Saved plugins are now stored in UI-specific keys, which are passed to gaim_plugins_load_saved(). If you're using CVS (shame on you!) you'll need to reload your plugins, and if you're careful enough, remove the old plugins tree from prefs.xml (/core/plugins/loaded/...). I assume no responsibility if you destroy prefs.xml, delete your harddrive, or sell your soul to a goat. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Tue, 24 Jun 2003 03:50:31 +0000
parents 158196b2db19
children 70d5122bc3ff
line wrap: on
line diff
--- a/src/plugin.h	Tue Jun 24 03:49:11 2003 +0000
+++ b/src/plugin.h	Tue Jun 24 03:50:31 2003 +0000
@@ -253,9 +253,12 @@
 void gaim_plugins_destroy_all(void);
 
 /**
  * Attempts to load all the plugins that were loaded when gaim last quit
  */
-void gaim_plugins_load_saved(void);
+void gaim_plugins_load_saved(const char *key);
 
 /**
  * Probes for plugins in the registered module paths.
@@ -253,9 +253,12 @@
 
 /**
- * Attempts to load all the plugins that were loaded when gaim last quit
+ * Attempts to load all the plugins in the specified preference key
+ * that were loaded when gaim last quit.
+ *
+ * @param key The preference key containing the list of plugins.
  */